/* ============================================================
 * File  : tetrahedron.cpp
 * Author: Stephane Gibault
 * Date  : Sun Feb 4 2007
 * Description :
 *
 * 
 *  (C) 2007 by Stephane Gibault
 *
 * This program is free software; you can redistribute it
 * and/or modify it under the terms of the GNU General
 * Public License as published by the Free Software Foundation;
 * either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * ============================================================ */

#include <QtOpenGL>
#include "tetrahedron.h"
#include <math.h>

Tetrahedron::Tetrahedron(QWidget *parent)
    : QGLWidget(parent)
{
	setFormat(QGLFormat(QGL::DirectRendering | QGL::DepthBuffer));  // | QGL::NoAccumBuffer
    	rotationX = 0.0;
    	rotationY = 0.0;
    	rotationZ = 0.0;
    	deplacementX = 0.0;
    	deplacementY = 0.0;
	zoom = -10.0;
	debut_px = 0;
	debut_py = 0;
	debut_pz = -10;
	debut_rx = 0;
	debut_ry = 0;
	debut_rz = 0;
	//
	fin_px = 0;
	fin_py = 0;
	fin_pz = -10;
	fin_rx = 0;
	fin_ry = 0;
	fin_rz = 0;
	//
	posanim_x = 0;
	posanim_y = 0;
	sizanim = 1.0f;
	iseffect = 0;
	ismblur = 0;
	path_fond = "$N$U$L$L";
	type3D = 0;
	//
	w_x_p = 2;
	w_x_m = -2;
	//
	myvariance = 1;
	sensvariance = 0.001;
	QImage wl_img_dec(128,128,QImage::Format_ARGB32_Premultiplied);
	wl_img_dec.fill(0);
	null_img = wl_img_dec.copy ( 0, 0, 128, 128);
	//
	table_puissance[0] = 2;
	table_puissance[1] = 4;
	table_puissance[2] = 8;
	table_puissance[3] = 16;
	table_puissance[4] = 32;
	table_puissance[5] = 64;
	table_puissance[6] = 128;
	table_puissance[7] = 256;
	table_puissance[8] = 512;
	table_puissance[9] = 1024;
	table_puissance[10] = 2048;
	table_puissance[11] = 4096;
	table_puissance[12] = 8192;
	table_puissance[13] = 16384;
	//
	movie = new QMovie();
}

void Tetrahedron::load_effet(QString nomeffet)
{
	glDeleteTextures(1, &texture3 );

	if ( nomeffet == tr("Aucun") )
	{
		iseffect = 0;
	}
	else
	{
		iseffect = 1;
		delete movie;
		movie = new QMovie(wg_tet_library + "/BIB_ManSlide/Eff_sup/" + nomeffet);
		if ( movie->isValid() == true )
		{
			movie->setCacheMode( QMovie::CacheAll );
			movie->jumpToFrame( 0 );
			a = movie->currentImage();
			//
			int wl_indx = 0;
			if ( a.width() > a.height() )
			{
				while ( a.width() >= table_puissance[wl_indx] && wl_indx < 14 )
				{
					wl_indx = wl_indx + 1;
				}
			}
			else
			{
				while ( a.height() >= table_puissance[wl_indx] && wl_indx < 14 )
				{
					wl_indx = wl_indx + 1;
				}
			}
			wg_puis_001 = a.copy ( 0, 0, table_puissance[wl_indx], table_puissance[wl_indx]);
			size_anim = table_puissance[wl_indx];
			size_003 = (float)a.width() / (float)table_puissance[wl_indx];
			size_004 = 1-((float)a.height() / (float)table_puissance[wl_indx]);
			d = QGLWidget::convertToGLFormat( wg_puis_001 );
			glGenTextures( 1, &texture3 );
			glBindTexture( GL_TEXTURE_2D, texture3 );
			glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, d.width(), d.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, d.bits() );
			glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
		}
		else
		{
			qDebug() << "ERROR LOADING EFFECT TEXTURE - INIT POSITION - " << wg_tet_library + "/BIB_ManSlide/Eff_sup/" + nomeffet;
		}
	}
}

void Tetrahedron::sl_charge_image(QString pathimg, QString pathfond)
{
	glDeleteTextures(1, &texture2 );
	if ( pathimg.right(8) != "$N$U$L$L" )
	{
    		if ( b.load( pathimg ) == true )
		{
			int wl_indx = 0;
			if ( b.width() > b.height() )
			{
				while ( b.width() >= table_puissance[wl_indx] && wl_indx < 14 )
				{
					wl_indx = wl_indx + 1;
				}
			}
			else
			{
				while ( b.height() >= table_puissance[wl_indx] && wl_indx < 14 )
				{
					wl_indx = wl_indx + 1;
				}
			}
			QImage wl_puis_001(table_puissance[wl_indx],table_puissance[wl_indx],QImage::Format_ARGB32_Premultiplied);
			wl_puis_001 = b.copy ( 0, 0, table_puissance[wl_indx], table_puissance[wl_indx]);
			size_001 = (float)b.width() / (float)table_puissance[wl_indx];
			size_002 = 1-((float)b.height() / (float)table_puissance[wl_indx]);
			//
			float wratioimg = (float)b.width() / (float)b.height();
			w_x_p = (float)(0-(2 * wratioimg)) * -1;
    			f = QGLWidget::convertToGLFormat( wl_puis_001 );
    			glGenTextures( 1, &texture2 );
			glBindTexture( GL_TEXTURE_2D, texture2 );
			glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits() );
			glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
			w_x_m = w_x_p * -1;

			if ( type3D == 1 || type3D == 3 )
			{
				for(int x=0; x<45; x++)
				{
					for(int y=0; y<45; y++)
					{
						points[x][y][0]=float((x/5.0f)-4.5f);
						points[x][y][1]=float((y/5.0f)-4.5f);
						points[x][y][2]=float(sin((((x/3.0f)*40.0f)/360.0f)*3.141592654*2.0f));
					}
				}
			}
		}
		else
		{
			qDebug() << "ERROR LOADING TEXTURE PLANE *********************************";
		}
	}
	else
	{
		float wratioimg = (float)null_img.width() / (float)null_img.height();
		w_x_p = (float)(0-(2 * wratioimg)) * -1;
    		f = QGLWidget::convertToGLFormat( null_img );
    		glGenTextures( 1, &texture2 );
		glBindTexture( GL_TEXTURE_2D, texture2 );
		glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, f.width(), f.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits() );
		glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
		w_x_m = w_x_p * -1;
	}
	//
	if ( pathfond.right(8) != "$N$U$L$L" )
	{
		glDeleteTextures(1, &texture1 );
    		if ( c.load( pathfond ) == true )
		{
			QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
			wl_puis_001 = c.copy ( 0, 0, 1024, 1024);
			t = QGLWidget::convertToGLFormat( wl_puis_001 );
    			glGenTextures( 1, &texture1 );
			glBindTexture( GL_TEXTURE_2D, texture1 );
			glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, t.width(), t.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, t.bits() );
			glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
		}
		else
		{
			qDebug() << "ERROR LOADING TEXTURE BACKGROUND : " << pathfond;
		}
	}
	else
	{
		glDeleteTextures(1, &texture1 );
		//
    		t = QGLWidget::convertToGLFormat( null_img );
    		glGenTextures( 1, &texture1 );
		glBindTexture( GL_TEXTURE_2D, texture1 );
		glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, t.width(), t.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, t.bits() );
		glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
	}
}

void Tetrahedron::sl_play()
{
	bcle_tempo = 0;
	duree = wg_duree * 25;
	progress = 1;
	x_titre = -1.8;
	y_titre = 20.0;
	delta_px = (fin_px - debut_px) / (duree-1);
	delta_py = (fin_py - debut_py) / (duree-1);
	delta_pz = (fin_pz - debut_pz) / (duree-1);
	delta_rx = (fin_rx - debut_rx) / (duree-1);
	delta_ry = (fin_ry - debut_ry) / (duree-1);
	delta_rz = (fin_rz - debut_rz) / (duree-1);
    	rotationX = debut_rx;
    	rotationY = debut_ry;
    	rotationZ = debut_rz;
    	deplacementX = debut_px;
    	deplacementY = debut_py;
	zoom = debut_pz;
	poursuite = 0;
	delta_opacity = (end_opacity - start_opacity) / duree;
	delta_fog_opacity = (end_fog_opacity - start_fog_opacity) / duree;
	wg_percent = start_opacity;
	wg_percent_fog = start_fog_opacity;
	QTimer::singleShot(0, this, SLOT(updateMove()));
}

void Tetrahedron::sl_go_start()
{
	rotationX = debut_rx;
	rotationY = debut_ry;
	rotationZ = debut_rz;
	deplacementX = debut_px;
	deplacementY = debut_py;
	zoom = debut_pz;
	x_titre = -1.8;
	y_titre = 20.0;
	updateGL();
}

void Tetrahedron::sl_go_end()
{
	rotationX = fin_rx;
	rotationY = fin_ry;
	rotationZ = fin_rz;
	deplacementX = fin_px;
	deplacementY = fin_py;
	zoom = fin_pz;
	if ( effet_titre == 4 )
	{
		x_titre = -1.59;
		y_titre = -22;
	}
	else
	{
		x_titre = -1.8 + ( v_titre * ((wg_duree * 25) + (pause_debut * 25) + (pause_fin * 25)));
	}
	updateGL();
}

void Tetrahedron::updateMove()
{
	if ( progress >= duree + (pause_debut * 25) + (pause_fin * 25) )
	{
		progress = 0;
		wg_percent = start_opacity;
		wg_percent_fog = start_fog_opacity;
		rotationX = debut_rx;
		rotationY = debut_ry;
		rotationZ = debut_rz;
		deplacementX = debut_px;
		deplacementY = debut_py;
		zoom = debut_pz;
		bcle_tempo = 0;
		movie->jumpToFrame(0);
		x_titre = -1.8;
		y_titre = 20.0;
	}
	else
	{
		if ( progress >= (pause_debut * 25) && progress < (pause_debut * 25) + duree)
		{
			rotationX = rotationX + delta_rx;
			rotationY = rotationY + delta_ry;
			rotationZ = rotationZ + delta_rz;
			deplacementX = deplacementX + delta_px;
			deplacementY = deplacementY + delta_py;
			zoom = zoom + delta_pz;
			wg_percent = wg_percent + delta_opacity;
			wg_percent_fog = wg_percent_fog + delta_fog_opacity;

			if ( effet_titre == 4 )
			{
				if ( x_titre + 0.82 < -0.8f )
				{
					x_titre = x_titre + 0.03;
					y_titre = y_titre - 6;
				}
			}
		}
	}
	if ( effet_titre == 3 )
	{
		x_titre = x_titre + v_titre;
	}

	if ( iseffect > 0 )
	{
		if ( bcle_tempo >= vitanim )
		{
			glDeleteTextures( 1, &texture3 );
			if ( movie->jumpToNextFrame() == false )
			{
				movie->jumpToFrame(0);
			}
			a = movie->currentImage();
			wg_puis_001 = a.copy ( 0, 0, size_anim, size_anim);
			d = QGLWidget::convertToGLFormat( wg_puis_001 );
			glGenTextures( 1, &texture3 );
			glBindTexture( GL_TEXTURE_2D, texture3 );
			glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, d.width(), d.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, d.bits() );
			glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
			bcle_tempo = 0;
		}
		else
		{
			++bcle_tempo;
		}
	}
	if ( isfog == 1 )
	{
		sl_opacity(wg_percent_fog);
	}

	if ( poursuite == 0 )
	{
		++progress;
		updateGL();
		if ( iseffect == 0 )
		{
			QTimer::singleShot(30, this, SLOT(updateMove()));
		}
		else
		{
			QTimer::singleShot(20, this, SLOT(updateMove()));
		}
	}
	else
	{
		rotationX = debut_rx;
		rotationY = debut_ry;
		rotationZ = debut_rz;
		deplacementX = debut_px;
		deplacementY = debut_py;
		zoom = debut_pz;
		wg_percent = start_opacity;
		x_titre = -1.8;
		updateGL();
	}
}

void Tetrahedron::sl_stop()
{
	poursuite = 1;
	QTimer::singleShot(20, this, SLOT(sl_wait_stop()));	
}

void Tetrahedron::sl_wait_stop()
{
	if ( iseffect > 0 )
	{
		glDeleteTextures(1, &texture3 );
		movie->jumpToFrame(0);
		a = movie->currentImage();
		glGenTextures( 1, &texture3 );
		glBindTexture( GL_TEXTURE_2D, texture3 );
		glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, d.width(), d.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, d.bits() );
		glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
	}
    	rotationX = debut_rx;
    	rotationY = debut_ry;
    	rotationZ = debut_rz;
    	deplacementX = debut_px;
    	deplacementY = debut_py;
	wg_percent = start_opacity;
	x_titre = -1.8;
	y_titre = 20.0;
	zoom = debut_pz;
	bcle_render = 1;
	updateGL();
}

void Tetrahedron::sl_mark_deb()
{
	debut_px = deplacementX;
	debut_py = deplacementY;
	debut_pz = zoom;
	debut_rx = rotationX;
	debut_ry = rotationY;
	debut_rz = rotationZ;
}

void Tetrahedron::sl_mark_fin()
{
	fin_px = deplacementX;
	fin_py = deplacementY;
	fin_pz = zoom;
	fin_rx = rotationX;
	fin_ry = rotationY;
	fin_rz = rotationZ;
}

void Tetrahedron::initializeGL()
{
    	qglClearColor(Qt::black);
	glClearAccum(0.0, 0.0, 0.0, 1.0);
	glClear(GL_DEPTH_BUFFER_BIT|GL_COLOR_BUFFER_BIT);
	bcle_render = 0;
	//
 	fogcolor[0] = 0.5;
 	fogcolor[1] = 0.5;
 	fogcolor[2] = 0.5;
 	fogcolor[3] = 0.5;
 	GLint fogmode = GL_EXP;
 	glFogi (GL_FOG_MODE, fogmode);
 	glFogfv(GL_FOG_COLOR, fogcolor);
 	glFogf(GL_FOG_DENSITY, 0.30);
 	glFogf(GL_FOG_START, 1.0);
 	glFogf(GL_FOG_END, 10.0);
	glDisable(GL_FOG);
	glEnable( GL_DEPTH_TEST );
	glDisable( GL_NORMALIZE );
	glDisable( GL_DITHER );
	glDisable( GL_SMOOTH );
	glDisable( GL_LIGHTING );
	glDisable( GL_ALPHA_TEST );
	glDisable( GL_BLEND );
	glDisable( GL_STENCIL_TEST );
	//glDepthMask(GL_FALSE);
	glAlphaFunc(GL_GREATER, 0.0f);

 	glHint(GL_PERSPECTIVE_CORRECTION_HINT, GL_FASTEST);
	//
    	glMatrixMode(GL_MODELVIEW);
    	glEnable(GL_TEXTURE_2D);
	null_img.fill(1);
	t = QGLWidget::convertToGLFormat(null_img );
	glGenTextures( 1, &texture1 );
	glBindTexture( GL_TEXTURE_2D, texture1 );
	glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, t.width(), t.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, t.bits() );
	f = QGLWidget::convertToGLFormat( null_img );
	glGenTextures( 1, &texture2 );
	glBindTexture( GL_TEXTURE_2D, texture2 );
	glTexImage2D( GL_TEXTURE_2D, 0, 4, f.width(), f.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, f.bits() );
	glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST );
	d = QGLWidget::convertToGLFormat( null_img );
	glGenTextures( 1, &texture3 );
	glBindTexture( GL_TEXTURE_2D, texture3 );
	glTexImage2D( GL_TEXTURE_2D, 0, 4, d.width(), d.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, d.bits() );
	glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_NEAREST );
}

void Tetrahedron::change_fog_color()
{
 	//GLint fogmode = GL_EXP;
 	glFogfv(GL_FOG_COLOR, fogcolor);
}

void Tetrahedron::sl_opacity(int wopacity)
{
	float recval = (float)wopacity;
	GLfloat fopacity;
	fopacity = recval / 100;
	glFogfv(GL_FOG_DENSITY, &fopacity);
	updateGL();
}

void Tetrahedron::sl_brouillard(int wstate)
{
	isfog = wstate;
	if ( wstate == 0)
	{
		glDisable(GL_FOG);
	}
	else
	{
		glEnable(GL_FOG);
	}
	updateGL();
}

void Tetrahedron::resizeGL(int width, int height)
{
    	glViewport(0, 0, width, height);
    	glMatrixMode(GL_PROJECTION);
	glLoadIdentity();
    	GLfloat szx = GLfloat(width) / height;
    	glFrustum(-szx, szx, -1.0, 1.0, 1.9, 20.0);
    	glMatrixMode(GL_MODELVIEW);
}

void Tetrahedron::paintGL()
{
    	glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    	draw();
}

void Tetrahedron::sl_change_fond(QString myfic)
{
	if ( myfic.right(8) != "$N$U$L$L" )
	{
		path_fond = myfic;
		glDeleteTextures(1, &texture1 );
		c.load( myfic );
		//
		QImage wl_puis_001(1024,1024,QImage::Format_ARGB32_Premultiplied);
		wl_puis_001 = c.copy ( 0, 0, 1024, 1024);
		t = QGLWidget::convertToGLFormat( wl_puis_001 );
		glGenTextures( 1, &texture1 );
		glBindTexture( GL_TEXTURE_2D, texture1 );
		glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, t.width(), t.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, t.bits() );
		glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
	}
	else
	{
		glDeleteTextures(1, &texture1 );
		t = QGLWidget::convertToGLFormat( null_img );
		glGenTextures( 1, &texture1 );
		glBindTexture( GL_TEXTURE_2D, texture1 );
		glTexImage2D( GL_TEXTURE_2D, 0, GL_RGBA, t.width(), t.height(), 0, GL_RGBA, GL_UNSIGNED_BYTE, t.bits() );
		glTexParameteri( GL_TEXTURE_2D, GL_TEXTURE_MIN_FILTER, GL_LINEAR );
	}
}

void Tetrahedron::mousePressEvent(QMouseEvent *event)
{
    	lastPos = event->pos();
}

void Tetrahedron::wheelEvent(QWheelEvent *event)
{
	if ( event->delta() > 0 )
	{
		if ( zoom < -2.1 )
		{
			zoom = zoom + 0.1;
		}
	}
	else
	{
		if ( zoom > -16.9 )
		{
			zoom = zoom - 0.1;
		}
	}
	updateGL();
}

void Tetrahedron::mouseMoveEvent(QMouseEvent *event)
{
    	GLfloat dx = GLfloat(event->x() - lastPos.x()) / width();
    	GLfloat dy = GLfloat(event->y() - lastPos.y()) / height();

    	if (event->buttons() & Qt::LeftButton) 
	{
		if ( tool == 2 )
		{
			deplacementX += (dx * (zoom * -1));
        		deplacementY += (dy * (zoom * -1)) * -1;
		}
		else
		{
			if ( tool == 1 )
			{
				if ( event->x() > lastPos.x() )
				{
					if ( zoom < -2.1 )
					{
						zoom = zoom + 0.1;
					}
				}
				else
				{
					if ( zoom > -16.9 )
					{
						zoom = zoom - 0.1;
					}
				}
			}
			else
			{
				if ( tool == 3 )
				{
					if ( event->x() > lastPos.x() )
					{
						rotationX = rotationX + (1 * (event->x() - lastPos.x()));
					}
					else
					{
						rotationX = rotationX - (1 * (lastPos.x() - event->x()));
					}
				}
				else
				{
					if ( tool == 4 )
					{
						if ( event->x() > lastPos.x() )
						{
							rotationY = rotationY + (1 * (event->x() - lastPos.x()));
						}
						else
						{
							rotationY = rotationY - (1 * (lastPos.x() - event->x()));
						}
					}
					else
					{
						if ( tool == 5 )
						{
							if ( event->x() > lastPos.x() )
							{
								rotationZ = rotationZ + (1 * (event->x() - lastPos.x()));
							}
							else
							{
								rotationZ = rotationZ - (1 * (lastPos.x() - event->x()));
							}
						}
						else
						{
						if ( tool == 6 )
						{
								if ( event->x() > lastPos.x() )
								{
									rotationY = rotationY + (1 * (event->x() - lastPos.x()));
								}
								else
								{
									rotationY = rotationY - (1 * (lastPos.x() - event->x()));
								}
								if ( event->y() > lastPos.y() )
								{
									rotationX = rotationX + (1 * (event->y() - lastPos.y()));
								}
								else
								{
									rotationX = rotationX - (1 * (lastPos.y() - event->y()));
								}
								if ( event->x() > lastPos.x() & event->y() > lastPos.y())
								{
									rotationZ = rotationZ + (1 * (event->x() - lastPos.x()));
								}
								else
								{
									if ( event->x() < lastPos.x() & event->y() < lastPos.y())
									rotationZ = rotationZ - (1 * (lastPos.x() - event->x()));
								}
							}
						}
					}
				}
			} 
		}
        	updateGL();
	}
	else
	{
    		if (event->buttons() & Qt::RightButton) 
		{
			deplacementX += (dx * (zoom * -1));
        		deplacementY += (dy * (zoom * -1)) * -1;
			updateGL();
		}
	}
    	lastPos = event->pos();
}

void Tetrahedron::draw()
{
	if ( bcle_render == 1 )
	{
		glClearAccum(0.0, 0.0, 0.0, 1.0);
		glClear(GL_DEPTH_BUFFER_BIT|GL_COLOR_BUFFER_BIT);
	}
	glEnable(GL_BLEND);
	glBlendFunc(GL_ONE, GL_ZERO);
	if ( path_fond == "$N$U$L$L" )
	{
	}
	else
	{
		glLoadIdentity(); // *** Renouvellement matrice ***
		glTranslatef(0.0f, 0.0f, -19.9f);
		glBindTexture( GL_TEXTURE_2D, texture1 );
		glBegin(GL_QUADS);
		glTexCoord2f(0.703125f, 0.4375f);
		glVertex3f( 14.0f, -11.2f, 0.0f); 
		glTexCoord2f(0.703125f, 1.0f);
		glVertex3f(14.0f, 11.2f, 0.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f(-14.0f, 11.2f, 0.0f);
		glTexCoord2f(0.0f, 0.4375f);
		glVertex3f(-14.0f, -11.2f, 0.0f);
		glEnd();
	}
	if ( isbackanim == 1 && iseffect > 0 )
	{
		glLoadIdentity(); // *** Renouvellement matrice ***
		glTranslatef(posanim_x, posanim_y, -19.8f);
    		glRotatef(-rotanim, 0.0, 0.0, 1.0);
		glColor4f(1.0f,1.0f,1.0f,wg_percent);
		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
		glBindTexture( GL_TEXTURE_2D, texture3 );
		glBegin(GL_QUADS);
		glTexCoord2f(size_003, size_004);
		glVertex3f( 14.0f * sizanim, -11.2f * sizanim, 0.0f); 
		glTexCoord2f(size_003, 1.0f);
		glVertex3f(14.0f * sizanim, 11.2f * sizanim, 0.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f(-14.0f * sizanim, 11.2f * sizanim, 0.0f);
		glTexCoord2f(0.0f, size_004);
		glVertex3f(-14.0f * sizanim, -11.2f * sizanim, 0.0f);
    		glEnd();
	}
	//
 	glLoadIdentity(); // *** Renouvellement matrice ***
// *** Transformations ***
	glTranslatef(deplacementX, deplacementY, zoom);
	glRotatef(rotationX, 1.0, 0.0, 0.0);
   	glRotatef(rotationY, 0.0, 1.0, 0.0);
    	glRotatef(rotationZ, 0.0, 0.0, 1.0);
// *** Gestion de la texture ***
	//
    	glBindTexture( GL_TEXTURE_2D, texture2 );
	glColor4f(1.0f,1.0f,1.0f,wg_percent_slide);
	glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
	glDepthMask(0);
// *** Creation des elements du dessin ***
	glBegin(GL_QUADS);

	switch(type3D)
	{
	case 0:
    		glTexCoord2f(size_001, size_002); // A  SIZE_001 et 002 remplace 1.0
    		glVertex3f(w_x_p * size_factor, -2.0f * size_factor, 0.0f);

    		glTexCoord2f(size_001, 1.0f); // B
    		glVertex3f(w_x_p * size_factor, 2.0f * size_factor, 0.0f);

    		glTexCoord2f(0.0f, 1.0f); // C
    		glVertex3f(w_x_m * size_factor, 2.0f * size_factor, 0.0f);

    		glTexCoord2f(0.0f, size_002); // D
    		glVertex3f(w_x_m * size_factor, -2.0f * size_factor, 0.0f);
		break;
	case 1:
		for( x = 0; x < 44; x++ )				// Loop Through The X Plane (44 Points)
		{
			for( y = 0; y < 44; y++ )			// Loop Through The Y Plane (44 Points)
			{
				float_x = (float(x)/44)*size_001;			// Create A Floating Point X Value
				float_y = (float(y*(1-size_002))/44)+size_002;			// Create A Floating Point Y Value
				float_xb = (float(x+1)/44)*size_001;		// Create A Floating Point Y Value+0.0227f
				float_yb = (float((y+1)*(1-size_002))/44)+size_002;		// Create A Floating Point Y Value+0.0227f
				glTexCoord2f( float_x, float_y);	// First Texture Coordinate (Bottom Left)
				glVertex3f( points[x][y][0] * size_factor, points[x][y][1] * size_factor, points[x][y][2] * size_factor );
	
				glTexCoord2f( float_x, float_yb );	// Second Texture Coordinate (Top Left)
				glVertex3f( points[x][y+1][0] * size_factor, points[x][y+1][1] * size_factor, points[x][y+1][2] * size_factor );
			
				glTexCoord2f( float_xb, float_yb );	// Third Texture Coordinate (Top Right)
				glVertex3f( points[x+1][y+1][0] * size_factor, points[x+1][y+1][1] * size_factor, points[x+1][y+1][2] * size_factor );
			
				glTexCoord2f( float_xb, float_y );	// Fourth Texture Coordinate (Bottom Right)
				glVertex3f( points[x+1][y][0] * size_factor, points[x+1][y][1] * size_factor, points[x+1][y][2] * size_factor );
			}
		}
		break;
	case 2:
		// Back Face
		//glNormal3f( 0.0f, 0.0f,-1.0f);					// Normal Pointing Away From Viewer
		glTexCoord2f(size_001, size_002); glVertex3f(-1.0f * size_factor, -1.0f * size_factor, -1.0f * size_factor);	// Point 1 (Back)
		glTexCoord2f(size_001, 1.0f); glVertex3f(-1.0f * size_factor,  1.0f * size_factor, -1.0f * size_factor);	// Point 2 (Back)
		glTexCoord2f(0.0f, 1.0f); glVertex3f( 1.0f * size_factor,  1.0f * size_factor, -1.0f * size_factor);	// Point 3 (Back)
		glTexCoord2f(0.0f, size_002); glVertex3f( 1.0f * size_factor, -1.0f * size_factor, -1.0f * size_factor);	// Point 4 (Back)
		// Top Face
		//glNormal3f( 0.0f, 1.0f, 0.0f);					// Normal Pointing Up
		glTexCoord2f(0.0f, 1.0f); glVertex3f(-1.0f * size_factor,  1.0f * size_factor, -1.0f * size_factor);	// Point 1 (Top)
		glTexCoord2f(0.0f, size_002); glVertex3f(-1.0f * size_factor,  1.0f * size_factor,  1.0f);	// Point 2 (Top)
		glTexCoord2f(size_001, size_002); glVertex3f( 1.0f * size_factor,  1.0f * size_factor,  1.0f);	// Point 3 (Top)
		glTexCoord2f(size_001, 1.0f); glVertex3f( 1.0f * size_factor,  1.0f * size_factor, -1.0f * size_factor);	// Point 4 (Top)
		// Bottom Face
		//glNormal3f( 0.0f,-1.0f, 0.0f);					// Normal Pointing Down
		glTexCoord2f(size_001, 1.0f); glVertex3f(-1.0f * size_factor, -1.0f * size_factor, -1.0f * size_factor);	// Point 1 (Bottom)
		glTexCoord2f(0.0f, 1.0f); glVertex3f( 1.0f * size_factor, -1.0f * size_factor, -1.0f * size_factor);	// Point 2 (Bottom)
		glTexCoord2f(0.0f, size_002); glVertex3f( 1.0f * size_factor, -1.0f * size_factor,  1.0f);	// Point 3 (Bottom)
		glTexCoord2f(size_001, size_002); glVertex3f(-1.0f * size_factor, -1.0f * size_factor,  1.0f);	// Point 4 (Bottom)
		// Right face
		//glNormal3f( 1.0f, 0.0f, 0.0f);					// Normal Pointing Right
		glTexCoord2f(size_001, 	size_002); glVertex3f( 1.0f * size_factor, -1.0f * size_factor, -1.0f * size_factor);	// Point 1 (Right)
		glTexCoord2f(size_001, 1.0f); glVertex3f( 1.0f * size_factor,  1.0f * size_factor, -1.0f * size_factor);	// Point 2 (Right)
		glTexCoord2f(0.0f, 1.0f); glVertex3f( 1.0f * size_factor,  1.0f * size_factor,  1.0f);	// Point 3 (Right)
		glTexCoord2f(0.0f, size_002); glVertex3f( 1.0f * size_factor, -1.0f * size_factor,  1.0f);	// Point 4 (Right)
		// Left Face
		//glNormal3f(-1.0f, 0.0f, 0.0f);					// Normal Pointing Left
		glTexCoord2f(0.0f, size_002); glVertex3f(-1.0f * size_factor, -1.0f * size_factor, -1.0f * size_factor);	// Point 1 (Left)
		glTexCoord2f(size_001, size_002); glVertex3f(-1.0f * size_factor, -1.0f * size_factor,  1.0f);	// Point 2 (Left)
		glTexCoord2f(size_001, 1.0f); glVertex3f(-1.0f * size_factor,  1.0f * size_factor,  1.0f);	// Point 3 (Left)
		glTexCoord2f(0.0f, 1.0f); glVertex3f(-1.0f * size_factor,  1.0f * size_factor, -1.0f * size_factor);	// Point 4 (Left)
		//
		glTexCoord2f(0.0f, size_002); glVertex3f(-1.0f * size_factor, -1.0f * size_factor,  1.0f);	// Point 1 (Front)
		glTexCoord2f(size_001, size_002); glVertex3f( 1.0f * size_factor, -1.0f * size_factor,  1.0f);	// Point 2 (Front)
		glTexCoord2f(size_001, 1.0f); glVertex3f( 1.0f * size_factor,  1.0f * size_factor,  1.0f);	// Point 3 (Front)
		glTexCoord2f(0.0f, 1.0f); glVertex3f(-1.0f * size_factor,  1.0f * size_factor,  1.0f);	// Point 4 (Front)
		//
		glEnd();	
		break;
	case 3:
		for( x = 0; x < 44; x++ )				// Loop Through The X Plane (44 Points)
		{
			for(z=0; z<45; z++)
			{
				for(int y=0; y<45; y++)
				{
					points[z][y][2]=float(sin((((z/3.0f)*40)/360.0f)*3.141592654*myvariance));
				}
			}
			myvariance = myvariance + sensvariance;
			if ( myvariance > 4 )
			{
				sensvariance = -0.001;
			}
			if ( myvariance < 1 )
			{
				sensvariance = +0.001;
			}
			for( y = 0; y < 44; y++ )			// Loop Through The Y Plane (44 Points)
			{
				float_x = (float(x)/44)*size_001;			// Create A Floating Point X Value
				float_y = (float(y*(1-size_002))/44)+size_002;			// Create A Floating Point Y Value
				float_xb = (float(x+1)/44)*size_001;		// Create A Floating Point Y Value+0.0227f
				float_yb = (float((y+1)*(1-size_002))/44)+size_002;		// Create A Floating Point Y Value+0.0227f
				glTexCoord2f( float_x, float_y);	// First Texture Coordinate (Bottom Left)
				glVertex3f( points[x][y][0] * size_factor, points[x][y][1] * size_factor, points[x][y][2] * size_factor );
		
				glTexCoord2f( float_x, float_yb );	// Second Texture Coordinate (Top Left)
				glVertex3f( points[x][y+1][0] * size_factor, points[x][y+1][1] * size_factor, points[x][y+1][2] * size_factor );
			
				glTexCoord2f( float_xb, float_yb );	// Third Texture Coordinate (Top Right)
				glVertex3f( points[x+1][y+1][0] * size_factor, points[x+1][y+1][1] * size_factor, points[x+1][y+1][2] * size_factor );
			
				glTexCoord2f( float_xb, float_y );	// Fourth Texture Coordinate (Bottom Right)
				glVertex3f( points[x+1][y][0] * size_factor, points[x+1][y][1] * size_factor, points[x+1][y][2] * size_factor );
			}
		}
		break;
	case 4:
		glTexCoord2f(size_001, size_002);
		glVertex3f(w_x_p * size_factor, -2.0f * size_factor, 0.0f);
		glTexCoord2f(size_001, size_002 + ((1-size_002)/2));
		glVertex3f(w_x_p * size_factor, -0.1f, 0.0f);
		glTexCoord2f(size_001/2, size_002 + ((1-size_002)/2));
		glVertex3f(0.1f, -0.1f, 0.0f);
		glTexCoord2f(size_001/2, size_002);
		glVertex3f(0.1f, -2.0f * size_factor, 0.0f);
		//
		glTexCoord2f(size_001, size_002 + ((1-size_002)/2));
		glVertex3f(w_x_p * size_factor, 0.1f, 0.0f);
		glTexCoord2f(size_001, 1.0f);
		glVertex3f(w_x_p * size_factor, 2.0f * size_factor, 0.0f);
		glTexCoord2f(size_001/2, 1.0f);
		glVertex3f(0.1f, 2.0f * size_factor, 0.0f);
		glTexCoord2f(size_001/2, size_002 + ((1-size_002)/2));
		glVertex3f(0.1f, 0.1f * size_factor, 0.0f);
		//
		glTexCoord2f(size_001/2, size_002 + ((1-size_002)/2));
		glVertex3f(-0.1f, 0.1f, 0.0f);
		glTexCoord2f(size_001/2, 1.0f);
		glVertex3f(-0.1f, 2.0f * size_factor, 0.0f);
		glTexCoord2f(0.0f, 1.0f);
		glVertex3f(w_x_m * size_factor, 2.0f * size_factor, 0.0f);
		glTexCoord2f(0.0f, size_002 + ((1-size_002)/2));
		glVertex3f(w_x_m * size_factor, 0.1f, 0.0f);
		//
		glTexCoord2f(size_001/2, size_002);
		glVertex3f(-0.1f, -2.0f * size_factor, 0.0f);
		glTexCoord2f(size_001/2, size_002 + ((1-size_002)/2));
		glVertex3f(-0.1f, -0.1f, 0.0f);
		glTexCoord2f(0.0f, size_002 + ((1-size_002)/2));
		glVertex3f(w_x_m * size_factor, -0.1f, 0.0f);
		glTexCoord2f(0.0f, size_002);
		glVertex3f(w_x_m * size_factor, -2.0f * size_factor, 0.0f);
		break;
	case 5:
		glTexCoord2f(size_001, size_002); // A
		glVertex3f((w_x_p * size_factor)/2, -2.0f * size_factor, 0.0f);

		glTexCoord2f(size_001, 1.0f); // B
		glVertex3f((w_x_p * size_factor)/2, 2.0f * size_factor, 0.0f);

		glTexCoord2f(size_001/2, 1.0f); // C
		glVertex3f((w_x_m * size_factor)/2, 2.0f * size_factor, 0.0f);

		glTexCoord2f(size_001/2, size_002); // D
		glVertex3f((w_x_m * size_factor)/2, -2.0f * size_factor, 0.0f);
		//
		glTexCoord2f(0.0f, size_002); // A
		glVertex3f((w_x_p * size_factor)/2, -2.0f * size_factor, -0.01f);

		glTexCoord2f(0.0f, 1.0f); // B
		glVertex3f((w_x_p * size_factor)/2, 2.0f * size_factor, -0.01f);

		glTexCoord2f(size_001/2, 1.0f); // C
		glVertex3f((w_x_m * size_factor)/2, 2.0f * size_factor, -0.01f);

		glTexCoord2f(size_001/2, size_002); // D
		glVertex3f((w_x_m * size_factor)/2, -2.0f * size_factor, -0.01f);
		break;
	case 6:
		glTexCoord2f(size_001, size_002 + ((1-size_002)/2)); // A
		glVertex3f(w_x_p * size_factor, (-2.0f * size_factor)/2, 0.0f);

		glTexCoord2f(size_001, 1.0f); // B
		glVertex3f(w_x_p * size_factor, (2.0f * size_factor)/2, 0.0f);

		glTexCoord2f(0.0f, 1.0f); // C
		glVertex3f(w_x_m * size_factor, (2.0f * size_factor)/2, 0.0f);

		glTexCoord2f(0.0f, size_002 + ((1-size_002)/2)); // D
		glVertex3f(w_x_m * size_factor, (-2.0f * size_factor)/2, 0.0f);
		//
		glTexCoord2f(size_001, size_002); // A
		glVertex3f(w_x_p * size_factor, (-2.0f * size_factor)/2, -0.01f);

		glTexCoord2f(size_001, size_002 + ((1-size_002)/2)); // B
		glVertex3f(w_x_p * size_factor, (2.0f * size_factor)/2, -0.01f);

		glTexCoord2f(0.0f, size_002 + ((1-size_002)/2)); // C
		glVertex3f(w_x_m * size_factor, (2.0f * size_factor)/2, -0.01f);

		glTexCoord2f(0.0f, size_002); // D
		glVertex3f(w_x_m * size_factor, (-2.0f * size_factor)/2, -0.01f);
		break;
	case 7:
		glTexCoord2f(size_001, size_002); // A
		glVertex3f((w_x_p * size_factor), -2.0f * size_factor, 0.0f);

		glTexCoord2f(size_001, 1.0f); // B
		glVertex3f((w_x_p * size_factor), 2.0f * size_factor, 0.0f);

		glTexCoord2f(size_001/2, 1.0f); // C
		glVertex3f(0.0f, 2.0f * size_factor, -0.8f);

		glTexCoord2f(size_001/2, size_002); // D
		glVertex3f(0.0f, -2.0f * size_factor, -0.8f);
		//
		glTexCoord2f(size_001/2, size_002); // D
		glVertex3f(0.0f, -2.0f * size_factor, -0.8f);

		glTexCoord2f(size_001/2, 1.0f); // C
		glVertex3f(0.0f, 2.0f * size_factor, -0.8f);

		glTexCoord2f(0.0f, 1.0f); // B
		glVertex3f((w_x_m * size_factor), 2.0f * size_factor, 0.0f);

		glTexCoord2f(0.0f, size_002); // A
		glVertex3f((w_x_m * size_factor), -2.0f * size_factor, 0.0f);
		break;
	}
	//
    	glEnd();

	//
	if ( isbackanim == 0 && iseffect > 0 )
	{
		glLoadIdentity(); // *** Renouvellement matrice ***
		glTranslatef(posanim_x, posanim_y, -2.0f);
    		glRotatef(-rotanim, 0.0, 0.0, 1.0);
		glColor4f(1.0f,1.0f,1.0f,wg_percent);
		glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
		glBindTexture( GL_TEXTURE_2D, texture3 );
		glBegin(GL_QUADS);
		glTexCoord2f(size_003, size_004);
    		glVertex3f(1.41f * sizanim, -1.128f * sizanim, 0.0f);
		glTexCoord2f(size_003, 1.0f);
    		glVertex3f(1.41f * sizanim, 1.128f * sizanim, 0.0f);
		glTexCoord2f(0.0f, 1.0f);
    		glVertex3f(-1.41f * sizanim, 1.128f * sizanim, 0.0f);
		glTexCoord2f(0.0f, size_004);
    		glVertex3f(-1.41f * sizanim, -1.128f * sizanim, 0.0f);
    		glEnd();
	}
	//
	if ( txt_sur_image == "" )
	{
	}
	else
	{
		glLoadIdentity();
		qglColor ( txt_mycolor );
		if ( effet_titre == 0 )
		{
			renderText ( 0, this->height() - 20, txt_sur_image, myfont );
		}
		else
		{
			if ( effet_titre == 1 )
			{
				renderText ( 0, 20, txt_sur_image, myfont );
			}
			else
			{
				if ( effet_titre == 2 )
				{
					renderText ( 0, this->height() / 2, txt_sur_image, myfont );
				}
				else
				{
					if ( effet_titre == 3 )
					{
						renderText ( x_titre, this->height() - 20, txt_sur_image, myfont );
					}
					else
					{
						glTranslatef(0.0f, x_titre + 0.80, -1.9f);
						glEnable(GL_BLEND);
						glBlendFunc (GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
        					glBegin(GL_QUADS);
	    					glColor4f(0.0f, 0.0f, 0.0f, 0.5f);
            					glVertex3f(1.5f, -1.08f, 0.0f);
            					glVertex3f(1.5f, 0.0f, 0.0f);
            					glVertex3f(-1.5f, 0.0f, 0.0f);
            					glVertex3f(-1.5f, -1.08f, 0.0f);
        					glEnd();
						glDisable(GL_BLEND);
	    					glColor4f(1.0f, 1.0f, 1.0f, 1.0f);
						if ( this->height() < 500 )
						{
							renderText ( 5, this->height() + (y_titre + 6), txt_sur_image, QFont(myfont.family(), 11) );
						}
						else
						{
							renderText ( 5, this->height() + (y_titre), txt_sur_image, QFont(myfont.family(), 11) );
						}
					}
				}
			}
		}
		QColor mycoul(255,255,255);
		qglColor ( mycoul );
	}
	glDepthMask(1);
	if ( ismblur == 1 )
	{
		if ( bcle_render == 1 )
		{
			glAccum(GL_LOAD, 0.1);
			glAccum(GL_ACCUM, 1.0);
			glAccum(GL_RETURN, 1.0);
			bcle_render = 2;
		}
		else
		{
			if ( bcle_render == 2 )
			{
				glAccum(GL_ACCUM, 0.1);
				glAccum(GL_MULT, 0.9);
				glAccum(GL_RETURN, 1.0);
			}
		}
	}
}

void Tetrahedron::grabframe(QString pathimg)
{
	QImage myimg = this->grabFrameBuffer ( false );
	myimg.save( pathimg ,"JPEG", 100 );
}

void Tetrahedron::grabgl()
{
	bufimg[cptbuf] = this->grabFrameBuffer ( false );
	++cptbuf; // = cptbuf + 1;
	if ( cptbuf == 200 || (duree - 1) <= progress )
	{
		wl_var_1 = "000000000";
		wg_cpt_001 = 0;
		while (wg_cpt_001 < cptbuf )
		{
			wl_var_2 = QString::number(frame_encoding);
			wl_var_1.replace( 9 - wl_var_2.length(), wl_var_2.length(), wl_var_2);
			bufimg[wg_cpt_001].save(path_render + "/Slide_xxx_" + wl_var_1 + ".jpg","JPEG",wg_qualite);
			frame_encoding = frame_encoding + 1;
			wg_cpt_001 = wg_cpt_001 + 1;
		}
		cptbuf = 0;
	}
	if ( duree < progress )
	{
		poursuite = 1;
	}	
}
